@@ -294,7 +294,7 @@ void GeodesicExact::ArcDirect(double lat1, double lon1, double azi1, double a12,
 //*****************************************************************************
 double GeodesicExact::GenDirect(double lat1, double lon1, double azi1,
                         bool arcmode, double s12_a12,
-                        NETGeographicLib::Mask outmask,
+                        GeodesicExact::mask outmask,
                         [System::Runtime::InteropServices::Out] double% lat2,
                         [System::Runtime::InteropServices::Out] double% lon2,
                         [System::Runtime::InteropServices::Out] double% azi2,
@@ -439,7 +439,7 @@ double GeodesicExact::Inverse(double lat1, double lon1, double lat2, double lon2
 
 //*****************************************************************************
 double GeodesicExact::GenInverse(double lat1, double lon1, double lat2, double lon2,
-                        NETGeographicLib::Mask outmask,
+                        GeodesicExact::mask outmask,
                         [System::Runtime::InteropServices::Out] double% s12,
                         [System::Runtime::InteropServices::Out] double% azi1,
                         [System::Runtime::InteropServices::Out] double% azi2,
