@@ -25,6 +25,7 @@ namespace Projections
         public MiscPanel()
         {
             InitializeComponent();
+            m_comboBox.SelectedIndex = 0;
         }
 
         private void OnConvertDMS(object sender, EventArgs e)
@@ -55,7 +56,18 @@ namespace Projections
                 m_longitudeDMSTextBox.Text = DMS.Encode(lon, 5, DMS.Flag.LONGITUDE, 0);
                 m_latitudeDMSTextBox.Text = DMS.Encode(lat, 5, DMS.Flag.LATITUDE, 0);
                 string tmp = "";
-                Geohash.Forward(lat, lon, 12, out tmp);
+                switch (m_comboBox.SelectedIndex)
+                {
+                    case 0: // Geohash
+                        Geohash.Forward(lat, lon, 12, out tmp);
+                        break;
+                    case 1: // GARS
+                        GARS.Forward(lat, lon, 2, out tmp);
+                        break;
+                    case 2: // Georef
+                        Georef.Forward(lat, lon, 2, out tmp);
+                        break;
+                }
                 m_geohashTextBox.Text = tmp;
             }
             catch (Exception xcpt)
@@ -68,9 +80,20 @@ namespace Projections
         {
             try
             {
-                double lat, lon;
+                double lat = 0.0, lon = 0.0;
                 int len;
-                Geohash.Reverse(m_geohashTextBox.Text, out lat, out lon, out len, true);
+                switch (m_comboBox.SelectedIndex)
+                {
+                    case 0: // Geohash
+                        Geohash.Reverse(m_geohashTextBox.Text, out lat, out lon, out len, true);
+                        break;
+                    case 1: // GARS
+                        GARS.Reverse(m_geohashTextBox.Text, out lat, out lon, out len, true);
+                        break;
+                    case 2: // Georef
+                        Georef.Reverse(m_geohashTextBox.Text, out lat, out lon, out len, true);
+                        break;
+                }
                 m_LongitudeTextBox.Text = lon.ToString();
                 m_latitudeTextBox.Text = lat.ToString();
                 m_longitudeDMSTextBox.Text = DMS.Encode(lon, 5, DMS.Flag.LONGITUDE, 0);
@@ -106,6 +129,10 @@ namespace Projections
                 Geohash.LatitudeResolution(12);
                 Geohash.LongitudeResolution(12);
                 Geohash.Reverse("djds54mrfc0g", out lat, out lon, out len, true);
+                GARS.Forward(32.0, -86.0, 2, out tmp);
+                GARS.Reverse("189LE37", out lat, out lon, out len, true);
+                Georef.Forward(32.0, -86.0, 2, out tmp);
+                Georef.Reverse("GJEC0000", out lat, out lon, out len, true);
                 MessageBox.Show("No errors detected", "OK", MessageBoxButtons.OK, MessageBoxIcon.Information);
             }
             catch (Exception xcpt)
