@@ -69,7 +69,6 @@ namespace GeographicLib {
   class GEOGRAPHICLIB_EXPORT CassiniSoldner {
   private:
     typedef Math::real real;
-    real eps1_, tiny_;
     Geodesic _earth;
     GeodesicLine _meridian;
     real _sbet0, _cbet0;
@@ -96,8 +95,7 @@ namespace GeographicLib {
      * @param[in] earth the Geodesic object to use for geodesic calculations.
      *   By default this uses the WGS84 ellipsoid.
      *
-     * \e lat0 should be in the range [&minus;90&deg;, 90&deg;] and \e
-     * lon0 should be in the range [&minus;540&deg;, 540&deg;).
+     * \e lat0 should be in the range [&minus;90&deg;, 90&deg;].
      **********************************************************************/
     CassiniSoldner(real lat0, real lon0,
                    const Geodesic& earth = Geodesic::WGS84());
@@ -108,8 +106,7 @@ namespace GeographicLib {
      * @param[in] lat0 latitude of center point of projection (degrees).
      * @param[in] lon0 longitude of center point of projection (degrees).
      *
-     * \e lat0 should be in the range [&minus;90&deg;, 90&deg;] and \e
-     * lon0 should be in the range [&minus;540&deg;, 540&deg;).
+     * \e lat0 should be in the range [&minus;90&deg;, 90&deg;].
      **********************************************************************/
     void Reset(real lat0, real lon0);
 
@@ -123,11 +120,10 @@ namespace GeographicLib {
      * @param[out] azi azimuth of easting direction at point (degrees).
      * @param[out] rk reciprocal of azimuthal northing scale at point.
      *
-     * \e lat should be in the range [&minus;90&deg;, 90&deg;] and \e
-     * lon should be in the range [&minus;540&deg;, 540&deg;).  A call
-     * to Forward followed by a call to Reverse will return the original (\e
-     * lat, \e lon) (to within roundoff).  The routine does nothing if the
-     * origin has not been set.
+     * \e lat should be in the range [&minus;90&deg;, 90&deg;].  A call to
+     * Forward followed by a call to Reverse will return the original (\e lat,
+     * \e lon) (to within roundoff).  The routine does nothing if the origin
+     * has not been set.
      **********************************************************************/
     void Forward(real lat, real lon,
                  real& x, real& y, real& azi, real& rk) const;
