@@ -2,7 +2,7 @@
  * \file GeodesicLine.hpp
  * \brief Header for GeographicLib::GeodesicLine class
  *
- * Copyright (c) Charles Karney (2009-2014) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2009-2015) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * http://geographiclib.sourceforge.net/
  **********************************************************************/
@@ -147,12 +147,16 @@ namespace GeographicLib {
        **********************************************************************/
       AREA          = Geodesic::AREA,
       /**
-       * Do not wrap \e lon2 in the direct calculation.
+       * Unroll \e lon2 in the direct calculation.  (This flag used to be
+       * called LONG_NOWRAP.)
        * @hideinitializer
        **********************************************************************/
-      LONG_NOWRAP   = Geodesic::LONG_NOWRAP,
+      LONG_UNROLL   = Geodesic::LONG_UNROLL,
+      /// \cond SKIP
+      LONG_NOWRAP   = LONG_UNROLL,
+      /// \endcond
       /**
-       * All capabilities, calculate everything.  (LONG_NOWRAP is not
+       * All capabilities, calculate everything.  (LONG_UNROLL is not
        * included in this mask.)
        * @hideinitializer
        **********************************************************************/
@@ -177,8 +181,7 @@ namespace GeographicLib {
      *   i.e., which quantities can be returned in calls to
      *   GeodesicLine::Position.
      *
-     * \e lat1 should be in the range [&minus;90&deg;, 90&deg;]; \e lon1 and \e
-     * azi1 should be in the range [&minus;540&deg;, 540&deg;).
+     * \e lat1 should be in the range [&minus;90&deg;, 90&deg;].
      *
      * The GeodesicLine::mask values are
      * - \e caps |= GeodesicLine::LATITUDE for the latitude \e lat2; this is
@@ -502,19 +505,17 @@ namespace GeographicLib {
      *   M12 and \e M21;
      * - \e outmask |= GeodesicLine::AREA for the area \e S12;
      * - \e outmask |= GeodesicLine::ALL for all of the above;
-     * - \e outmask |= GeodesicLine::LONG_NOWRAP stops the returned value of \e
-     *   lon2 being wrapped into the range [&minus;180&deg;, 180&deg;).
+     * - \e outmask |= GeodesicLine::LONG_UNROLL to unroll \e lon2 instead of
+     *   reducing it into the range [&minus;180&deg;, 180&deg;).
      * .
      * Requesting a value which the GeodesicLine object is not capable of
      * computing is not an error; the corresponding argument will not be
      * altered.  Note, however, that the arc length is always computed and
      * returned as the function value.
      *
-     * With the LONG_NOWRAP bit set, the quantity \e lon2 &minus; \e lon1
-     * indicates how many times the geodesic wrapped around the ellipsoid.
-     * Because \e lon2 might be outside the normal allowed range for
-     * longitudes, [&minus;540&deg;, 540&deg;), be sure to normalize it with
-     * Math::AngNormalize2 before using it in other GeographicLib calls.
+     * With the GeodesicLine::LONG_UNROLL bit set, the quantity \e lon2 &minus;
+     * \e lon1 indicates how many times and in what sense the geodesic
+     * encircles the ellipsoid.
      **********************************************************************/
     Math::real GenPosition(bool arcmode, real s12_a12, unsigned outmask,
                            real& lat2, real& lon2, real& azi2,
@@ -553,21 +554,21 @@ namespace GeographicLib {
     /**
      * @return \e azi0 the azimuth (degrees) of the geodesic line as it crosses
      *   the equator in a northward direction.
+     *
+     * The result lies in [&minus;90&deg;, 90&deg;].
      **********************************************************************/
     Math::real EquatorialAzimuth() const {
-      using std::atan2;
-      return Init() ?
-        atan2(_salp0, _calp0) / Math::degree() : Math::NaN();
+      return Init() ? Math::atan2d(_salp0, _calp0) : Math::NaN();
     }
 
     /**
      * @return \e a1 the arc length (degrees) between the northward equatorial
      *   crossing and point 1.
+     *
+     * The result lies in (&minus;180&deg;, 180&deg;].
      **********************************************************************/
     Math::real EquatorialArc() const {
-      using std::atan2;
-      return Init() ?
-        atan2(_ssig1, _csig1) / Math::degree() : Math::NaN();
+      return Init() ? Math::atan2d(_ssig1, _csig1) : Math::NaN();
     }
 
     /**
