@@ -2,7 +2,7 @@
  * \file MGRS.hpp
  * \brief Header for GeographicLib::MGRS class
  *
- * Copyright (c) Charles Karney (2008-2014) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2008-2015) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * http://geographiclib.sourceforge.net/
  **********************************************************************/
@@ -46,6 +46,11 @@ namespace GeographicLib {
    *   identity.  (This is affected in predictable ways by errors in
    *   determining the latitude band and by loss of precision in the MGRS
    *   coordinates.)
+   * - The trailing digits produced by Forward are consistent as the precision
+   *   is varied.  Specifically, the digits are obtained by operating on the
+   *   easting with &lfloor;10<sup>6</sup> <i>x</i>&rfloor; and extracting the
+   *   required digits from the resulting number (and similarly for the
+   *   northing).
    * - All MGRS coordinates truncate to legal 100 km blocks.  All MGRS
    *   coordinates with a legal 100 km block prefix are legal (even though the
    *   latitude band letter may now belong to a neighboring band).
@@ -69,21 +74,6 @@ namespace GeographicLib {
   class GEOGRAPHICLIB_EXPORT MGRS {
   private:
     typedef Math::real real;
-    // The smallest length s.t., 1.0e7 - eps() < 1.0e7 (approx 1.9 nm)
-    static inline real eps() {
-      using std::pow;
-      // 25 = ceil(log_2(2e7)) -- use half circumference here because
-      // northing 195e5 is a legal in the "southern" hemisphere.
-      static const real eps = pow(real(0.5), Math::digits() - 25);
-      return eps;
-    }
-    // The smallest angle s.t., 90 - angeps() < 90 (approx 50e-12 arcsec)
-    static inline real angeps() {
-      using std::pow;
-      // 7 = ceil(log_2(90))
-      static const real angeps = pow(real(0.5), Math::digits() - 7);
-      return angeps;
-    }
     static const std::string hemispheres_;
     static const std::string utmcols_[3];
     static const std::string utmrow_;
@@ -107,6 +97,8 @@ namespace GeographicLib {
       utmevenrowshift_ = 5,
       // Maximum precision is um
       maxprec_ = 5 + 6,
+      // For generating digits at maxprec
+      mult_ = 1000000,
     };
     static void CheckCoords(bool utmp, bool& northp, real& x, real& y);
     static int UTMRow(int iband, int icol, int irow);
@@ -182,15 +174,16 @@ namespace GeographicLib {
      *   allocated.
      *
      * \e prec specifies the precision of the MGRS string as follows:
-     * - prec = &minus;1 (min), only the grid zone is returned
-     * - prec = 0 (min), 100 km
-     * - prec = 1, 10 km
-     * - prec = 2, 1 km
-     * - prec = 3, 100 m
-     * - prec = 4, 10 m
-     * - prec = 5, 1 m
-     * - prec = 6, 0.1 m
-     * - prec = 11 (max), 1 &mu;m
+     * - \e prec = &minus;1 (min), only the grid zone is returned
+     * - \e prec = 0, 100 km
+     * - \e prec = 1, 10 km
+     * - \e prec = 2, 1 km
+     * - \e prec = 3, 100 m
+     * - \e prec = 4, 10 m
+     * - \e prec = 5, 1 m
+     * - \e prec = 6, 0.1 m
+     * - &hellip;
+     * - \e prec = 11 (max), 1 &mu;m
      *
      * UTM eastings are allowed to be in the range [100 km, 900 km], northings
      * are allowed to be in in [0 km, 9500 km] for the northern hemisphere and
@@ -293,18 +286,18 @@ namespace GeographicLib {
      * zones 1--9.)  In addition, MGRS coordinates with a neighboring
      * latitude band letter are permitted provided that some portion of the
      * 100 km block is within the given latitude band.  Thus
-     *   - 38VLS and 38WLS are allowed (latitude 64N intersects the square
-     *     38[VW]LS); but 38VMS is not permitted (all of 38VMS is north of 64N)
-     *   - 38MPE and 38NPF are permitted (they straddle the equator); but 38NPE
-     *     and 38MPF are not permitted (the equator does not intersect either
-     *     block).
-     *   - Similarly ZAB and YZB are permitted (they straddle the prime
-     *     meridian); but YAB and ZZB are not (the prime meridian does not
-     *     intersect either block).
+     * - 38VLS and 38WLS are allowed (latitude 64N intersects the square
+     *   38[VW]LS); but 38VMS is not permitted (all of 38WMS is north of 64N)
+     * - 38MPE and 38NPF are permitted (they straddle the equator); but 38NPE
+     *   and 38MPF are not permitted (the equator does not intersect either
+     *   block).
+     * - Similarly ZAB and YZB are permitted (they straddle the prime
+     *   meridian); but YAB and ZZB are not (the prime meridian does not
+     *   intersect either block).
      *
      * The UTM/UPS selection and the UTM zone is preserved in the conversion
      * from MGRS coordinate.  The conversion is exact for prec in [0, 5].  With
-     * centerp = true the conversion from MGRS to geographic and back is
+     * \e centerp = true, the conversion from MGRS to geographic and back is
      * stable.  This is not assured if \e centerp = false.
      *
      * If a "grid zone designation" (for example, 18T or A) is given, then some
@@ -343,6 +336,14 @@ namespace GeographicLib {
     static Math::real Flattening() { return UTMUPS::Flattening(); }
     ///@}
 
+    /**
+     * Perform some checks on the UTMUPS coordinates on this ellipsoid.  Throw
+     * an error if any of the assumptions made in the MGRS class is not true.
+     * This check needs to be carried out if the ellipsoid parameters (or the
+     * UTM/UPS scales) are ever changed.
+     **********************************************************************/
+    static void Check();
+
     /// \cond SKIP
     /**
      * <b>DEPRECATED</b>
