@@ -156,7 +156,9 @@ namespace GeographicLib {
      * @param[in] ndigits the number of bits of precision.
      * @return the resulting number of bits of precision.
      *
-     * This only has an effect when GEOGRAPHICLIB_PRECISION == 5.
+     * This only has an effect when GEOGRAPHICLIB_PRECISION == 5.  See also
+     * Utility::set_digits for caveats about when this routine should be
+     * called.
      **********************************************************************/
     static inline int set_digits(int ndigits) {
 #if GEOGRAPHICLIB_PRECISION != 5
@@ -372,7 +374,11 @@ namespace GeographicLib {
      * @param[in] y
      * @param[in] z
      * @return <i>xy</i> + <i>z</i>, correctly rounded (on those platforms with
-     *   support for the fma instruction).
+     *   support for the <code>fma</code> instruction).
+     *
+     * On platforms without the <code>fma</code> instruction, no attempt is
+     * made to improve on the result of a rounded multiplication followed by a
+     * rounded addition.
      **********************************************************************/
     template<typename T> static inline T fma(T x, T y, T z) {
 #if GEOGRAPHICLIB_CXX11_MATH
@@ -417,16 +423,41 @@ namespace GeographicLib {
     }
 
     /**
-     * Normalize an angle (restricted input range).
+     * Evaluate a polynomial.
+     *
+     * @tparam T the type of the arguments and returned value.
+     * @param[in] N the order of the polynomial.
+     * @param[in] p the coefficient array (of size \e N + 1).
+     * @param[in] x the variable.
+     * @return the value of the polynomial.
+     *
+     * Evaluate <i>y</i> = &sum;<sub><i>n</i>=0..<i>N</i></sub>
+     * <i>p</i><sub><i>n</i></sub> <i>x</i><sup><i>N</i>&minus;<i>n</i></sup>.
+     * Return 0 if \e N &lt; 0.  Return <i>p</i><sub>0</sub>, if \e N = 0 (even
+     * if \e x is infinite or a nan).  The evaluation uses Horner's method.
+     **********************************************************************/
+    template<typename T> static inline T polyval(int N, const T p[], T x)
+    { T y = N < 0 ? 0 : *p++; while (--N >= 0) y = y * x + *p++; return y; }
+
+    /**
+     * Normalize an angle.
      *
      * @tparam T the type of the argument and returned value.
      * @param[in] x the angle in degrees.
      * @return the angle reduced to the range [&minus;180&deg;, 180&deg;).
      *
-     * \e x must lie in [&minus;540&deg;, 540&deg;).
+     * The range of \e x is unrestricted.
      **********************************************************************/
-    template<typename T> static inline T AngNormalize(T x)
-    { return x >= 180 ? x - 360 : (x < -180 ? x + 360 : x); }
+    template<typename T> static inline T AngNormalize(T x) {
+#if GEOGRAPHICLIB_CXX11_MATH && GEOGRAPHICLIB_PRECISION != 4
+      using std::remainder;
+      x = remainder(x, T(360)); return x != 180 ? x : -180;
+#else
+      using std::fmod;
+      x = fmod(x, T(360));
+      return x < -180 ? x + 360 : (x < 180 ? x : x - 360);
+#endif
+    }
 
     /**
      * Normalize an arbitrary angle.
@@ -435,10 +466,21 @@ namespace GeographicLib {
      * @param[in] x the angle in degrees.
      * @return the angle reduced to the range [&minus;180&deg;, 180&deg;).
      *
-     * The range of \e x is unrestricted.
+     * <b>DEPRECATED</b>: use AngNormalize instead.
      **********************************************************************/
     template<typename T> static inline T AngNormalize2(T x)
-    { using std::fmod; return AngNormalize<T>(fmod(x, T(360))); }
+    { return AngNormalize<T>(x); }
+
+    /**
+     * Normalize a latitude.
+     *
+     * @tparam T the type of the argument and returned value.
+     * @param[in] x the angle in degrees.
+     * @return x if it is in the range [&minus;90&deg;, 90&deg;], otherwise
+     *   return NaN.
+     **********************************************************************/
+    template<typename T> static inline T LatFix(T x)
+    { using std::abs; return abs(x) > 90 ? NaN<T>() : x; }
 
     /**
      * Difference of two angles reduced to [&minus;180&deg;, 180&deg;]
@@ -449,19 +491,26 @@ namespace GeographicLib {
      * @return \e y &minus; \e x, reduced to the range [&minus;180&deg;,
      *   180&deg;].
      *
-     * \e x and \e y must both lie in [&minus;180&deg;, 180&deg;].  The result
-     * is equivalent to computing the difference exactly, reducing it to
-     * (&minus;180&deg;, 180&deg;] and rounding the result.  Note that this
-     * prescription allows &minus;180&deg; to be returned (e.g., if \e x is
-     * tiny and negative and \e y = 180&deg;).
+     * The result is equivalent to computing the difference exactly, reducing
+     * it to (&minus;180&deg;, 180&deg;] and rounding the result.  Note that
+     * this prescription allows &minus;180&deg; to be returned (e.g., if \e x
+     * is tiny and negative and \e y = 180&deg;).
      **********************************************************************/
     template<typename T> static inline T AngDiff(T x, T y) {
-      T t, d = sum(-x, y, t);
-      if ((d - T(180)) + t > T(0)) // y - x > 180
-        d -= T(360);            // exact
-      else if ((d + T(180)) + t <= T(0)) // y - x <= -180
-        d += T(360);            // exact
-      return d + t;
+#if GEOGRAPHICLIB_CXX11_MATH && GEOGRAPHICLIB_PRECISION != 4
+      using std::remainder;
+      T t, d = - AngNormalize(sum(remainder( x, T(360)),
+                                  remainder(-y, T(360)), t));
+#else
+      T t, d = - AngNormalize(sum(AngNormalize(x), AngNormalize(-y), t));
+#endif
+      // Here y - x = d - t (mod 360), exactly, where d is in (-180,180] and
+      // abs(t) <= eps (eps = 2^-45 for doubles).  The only case where the
+      // addition of t takes the result outside the range (-180,180] is d = 180
+      // and t < 0.  The case, d = -180 + eps, t = eps, can't happen, since
+      // sum would have returned the exact result in such a case (i.e., given t
+      // = 0).
+      return (d == 180 && t < 0 ? -180 : d) - t;
     }
 
     /**
@@ -476,7 +525,7 @@ namespace GeographicLib {
      * degrees.  (This is about 1000 times more resolution than we get with
      * angles around 90&deg;.)  We use this to avoid having to deal with near
      * singular cases when \e x is non-zero but tiny (e.g.,
-     * 10<sup>&minus;200</sup>).
+     * 10<sup>&minus;200</sup>).  This also converts -0 to +0.
      **********************************************************************/
     template<typename T> static inline T AngRound(T x) {
       using std::abs;
@@ -484,7 +533,114 @@ namespace GeographicLib {
       GEOGRAPHICLIB_VOLATILE T y = abs(x);
       // The compiler mustn't "simplify" z - (z - y) to y
       y = y < z ? z - (z - y) : y;
-      return x < 0 ? -y : y;
+#if GEOGRAPHICLIB_PRECISION == 4
+      // With quad precision and x = +/-0, this gives y = -0.  So change test
+      // to x <= 0 here to force +0 to be returned.
+      return x <= 0 ? 0 - y : y;
+#elif GEOGRAPHICLIB_PRECISION == 5
+      // With mpfr, 0 - y is a call to +=(int) which doesn't fix the sign of -0
+      return x < 0 ? T(0) - y : y;
+#else
+      return x < 0 ? 0 - y : y;
+#endif
+    }
+
+    /**
+     * Evaluate the sine and cosine function with the argument in degrees
+     *
+     * @tparam T the type of the arguments.
+     * @param[in] x in degrees.
+     * @param[out] sinx sin(<i>x</i>).
+     * @param[out] cosx cos(<i>x</i>).
+     *
+     * The results obey exactly the elementary properties of the trigonometric
+     * functions, e.g., sin 9&deg; = cos 81&deg; = &minus; sin 123456789&deg;.
+     **********************************************************************/
+    template<typename T> static inline void sincosd(T x, T& sinx, T& cosx) {
+      // In order to minimize round-off errors, this function exactly reduces
+      // the argument to the range [-45, 45] before converting it to radians.
+      using std::sin; using std::cos;
+      T r; int q;
+#if GEOGRAPHICLIB_CXX11_MATH && GEOGRAPHICLIB_PRECISION <= 3 && \
+  !defined(__GNUC__)
+      // Disable for gcc because of bug in glibc version < 2.22, see
+      //   https://sourceware.org/bugzilla/show_bug.cgi?id=17569
+      // Once this fix is widely deployed, should insert a runtime test for the
+      // glibc version number.
+      using std::remquo;
+      r = remquo(x, T(90), &q);
+#else
+      using std::fmod; using std::floor;
+      r = fmod(x, T(360));
+      q = int(floor(r / 90 + T(0.5)));
+      r -= 90 * q;
+#endif
+      // now abs(r) <= 45
+      r *= degree();
+      // Possibly could call the gnu extension sincos
+      T s = sin(r), c = cos(r);
+      switch (unsigned(q) & 3U) {
+      case 0U: sinx =     s; cosx =     c; break;
+      case 1U: sinx =     c; cosx = 0 - s; break;
+      case 2U: sinx = 0 - s; cosx = 0 - c; break;
+      default: sinx = 0 - c; cosx =     s; break; // case 3U
+      }
+    }
+
+    /**
+     * Evaluate the sine function with the argument in degrees
+     *
+     * @tparam T the type of the argument and the returned value.
+     * @param[in] x in degrees.
+     * @return sin(<i>x</i>).
+     **********************************************************************/
+    template<typename T> static inline T sind(T x) {
+      // See sincosd
+      using std::sin; using std::cos;
+      T r; int q;
+#if GEOGRAPHICLIB_CXX11_MATH && GEOGRAPHICLIB_PRECISION <= 3 && \
+  !defined(__GNUC__)
+      using std::remquo;
+      r = remquo(x, T(90), &q);
+#else
+      using std::fmod; using std::floor;
+      r = fmod(x, T(360));
+      q = int(floor(r / 90 + T(0.5)));
+      r -= 90 * q;
+#endif
+      // now abs(r) <= 45
+      r *= degree();
+      unsigned p = unsigned(q);
+      r = p & 1U ? cos(r) : sin(r);
+      return p & 2U ? 0 - r : r;
+    }
+
+    /**
+     * Evaluate the cosine function with the argument in degrees
+     *
+     * @tparam T the type of the argument and the returned value.
+     * @param[in] x in degrees.
+     * @return cos(<i>x</i>).
+     **********************************************************************/
+    template<typename T> static inline T cosd(T x) {
+      // See sincosd
+      using std::sin; using std::cos;
+      T r; int q;
+#if GEOGRAPHICLIB_CXX11_MATH && GEOGRAPHICLIB_PRECISION <= 3 && \
+  !defined(__GNUC__)
+      using std::remquo;
+      r = remquo(x, T(90), &q);
+#else
+      using std::fmod; using std::floor;
+      r = fmod(x, T(360));
+      q = int(floor(r / 90 + T(0.5)));
+      r -= 90 * q;
+#endif
+      // now abs(r) <= 45
+      r *= degree();
+      unsigned p = unsigned(q + 1);
+      r = p & 1U ? cos(r) : sin(r);
+      return p & 2U ? 0 - r : r;
     }
 
     /**
@@ -498,27 +654,10 @@ namespace GeographicLib {
      * returned.
      **********************************************************************/
     template<typename T> static inline T tand(T x) {
-      using std::abs; using std::tan;
-      static const T overflow = 1 / Math::sq(std::numeric_limits<T>::epsilon());
-      return abs(x) != 90 ? tan(x * Math::degree()) :
-        (x < 0 ? -overflow : overflow);
-    }
-
-    /**
-     * Evaluate the atan function with the result in degrees
-     *
-     * @tparam T the type of the argument and the returned value.
-     * @param[in] x
-     * @return atan(<i>x</i>) in degrees.
-     *
-     * Large values for the argument return &plusmn;90&deg;
-     **********************************************************************/
-    template<typename T> static inline T atand(T x) {
-      using std::abs; using std::atan;
-      static const T
-        overflow = 1 / (Math::sq(std::numeric_limits<T>::epsilon()) * 100);
-      return !(abs(x) >= overflow) ? atan(x) / Math::degree() :
-        (x > 0 ? 90 : -90);
+      static const T overflow = 1 / sq(std::numeric_limits<T>::epsilon());
+      T s, c;
+      sincosd(x, s, c);
+      return c ? s / c : (s < 0 ? -overflow : overflow);
     }
 
     /**
@@ -529,13 +668,46 @@ namespace GeographicLib {
      * @param[in] x
      * @return atan2(<i>y</i>, <i>x</i>) in degrees.
      *
-     * The result is in the range [&minus;180&deg; 180&deg;).
+     * The result is in the range [&minus;180&deg; 180&deg;).  N.B.,
+     * atan2d(&plusmn;0, &minus;1) = &minus;180&deg;; atan2d(+&epsilon;,
+     * &minus;1) = +180&deg;, for &epsilon; positive and tiny;
+     * atan2d(&plusmn;0, 1) = &plusmn;0&deg;.
      **********************************************************************/
     template<typename T> static inline T atan2d(T y, T x) {
-      using std::atan2;
-      return 0 - atan2(-y, x) / Math::degree();
+      // In order to minimize round-off errors, this function rearranges the
+      // arguments so that result of atan2 is in the range [-pi/4, pi/4] before
+      // converting it to degrees and mapping the result to the correct
+      // quadrant.
+      using std::atan2; using std::abs;
+      int q = 0;
+      if (abs(y) > abs(x)) { std::swap(x, y); q = 2; }
+      if (x < 0) { x = -x; ++q; }
+      // here x >= 0 and x >= abs(y), so angle is in [-pi/4, pi/4]
+      T ang = atan2(y, x) / degree();
+      switch (q) {
+        // Note that atan2d(-0.0, 1.0) will return -0.  However, we expect that
+        // atan2d will not be called with y = -0.  If need be, include
+        //
+        //   case 0: ang = 0 + ang; break;
+        //
+        // and handle mpfr as in AngRound.
+      case 1: ang = (y > 0 ? 180 : -180) - ang; break;
+      case 2: ang =  90 - ang; break;
+      case 3: ang = -90 + ang; break;
+      }
+      return ang;
     }
 
+    /**
+     * Evaluate the atan function with the result in degrees
+     *
+     * @tparam T the type of the argument and the returned value.
+     * @param[in] x
+     * @return atan(<i>x</i>) in degrees.
+     **********************************************************************/
+    template<typename T> static inline T atand(T x)
+    { return atan2d(x, T(1)); }
+
     /**
      * Evaluate <i>e</i> atanh(<i>e x</i>)
      *
