@@ -19,7 +19,8 @@ function [sinx, cosx] = sincosdx(x)
     q = floor(r / 90 + 0.5);
     r = r - 90 * q;
     q = mod(q, 4);
-    sinx = sind(r); cosx = cosd(r);
+    r = r * (pi/180);
+    sinx = sin(r); cosx = cos(r);
     t = q == 1; z = 0 - sinx(t); sinx(t) = cosx(t); cosx(t) = z;
     t = q == 2; sinx(t) = 0 - sinx(t); cosx(t) = 0 - cosx(t);
     t = q == 3; z = sinx(t); sinx(t) = 0 - cosx(t); cosx(t) = z;
