@@ -25,7 +25,7 @@ namespace GeographicLib {
     , tol_(sqrt(eps_))
     , tol0_(tol_ * sqrt(sqrt(eps_)))
     , _a(a)
-    , _f(f <= 1 ? f : 1/f)
+    , _f(f <= 1 ? f : 1/f)      // f > 1 behavior is DEPRECATED
     , _fm(1 - _f)
     , _e2(_f * (2 - _f))
     , _e(sqrt(abs(_e2)))
@@ -54,7 +54,7 @@ namespace GeographicLib {
     , tol_(sqrt(eps_))
     , tol0_(tol_ * sqrt(sqrt(eps_)))
     , _a(a)
-    , _f(f <= 1 ? f : 1/f)
+    , _f(f <= 1 ? f : 1/f)      // f > 1 behavior is DEPRECATED
     , _fm(1 - _f)
     , _e2(_f * (2 - _f))
     , _e(sqrt(abs(_e2)))
@@ -88,7 +88,7 @@ namespace GeographicLib {
     , tol_(sqrt(eps_))
     , tol0_(tol_ * sqrt(sqrt(eps_)))
     , _a(a)
-    , _f(f <= 1 ? f : 1/f)
+    , _f(f <= 1 ? f : 1/f)      // f > 1 behavior is DEPRECATED
     , _fm(1 - _f)
     , _e2(_f * (2 - _f))
     , _e(sqrt(abs(_e2)))
