@@ -2,7 +2,7 @@
  * \file AzimuthalEquidistant.cpp
  * \brief Implementation for GeographicLib::AzimuthalEquidistant class
  *
- * Copyright (c) Charles Karney (2009-2011) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2009-2015) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * http://geographiclib.sourceforge.net/
  **********************************************************************/
@@ -22,9 +22,8 @@ namespace GeographicLib {
     const {
     real sig, s, azi0, m;
     sig = _earth.Inverse(lat0, lon0, lat, lon, s, azi0, azi, m);
-    azi0 *= Math::degree();
-    x = s * sin(azi0);
-    y = s * cos(azi0);
+    Math::sincosd(azi0, x, y);
+    x *= s; y *= s;
     rk = !(sig <= eps_) ? m / s : 1;
   }
 
@@ -32,7 +31,7 @@ namespace GeographicLib {
                                      real& lat, real& lon, real& azi, real& rk)
     const {
     real
-      azi0 = atan2(x, y) / Math::degree(),
+      azi0 = Math::atan2d(x, y),
       s = Math::hypot(x, y);
     real sig, m;
     sig = _earth.Direct(lat0, lon0, azi0, s, lat, lon, azi, m);
