@@ -14,14 +14,10 @@ namespace GeographicLib {
   using namespace std;
 
   CassiniSoldner::CassiniSoldner(const Geodesic& earth)
-    : eps1_(real(0.01) * sqrt(numeric_limits<real>::epsilon()))
-    , tiny_(sqrt(numeric_limits<real>::min()))
-    , _earth(earth) {}
+    : _earth(earth) {}
 
   CassiniSoldner::CassiniSoldner(real lat0, real lon0, const Geodesic& earth)
-    : eps1_(real(0.01) * sqrt(numeric_limits<real>::epsilon()))
-    , tiny_(sqrt(numeric_limits<real>::min()))
-    , _earth(earth)
+    : _earth(earth)
   { Reset(lat0, lon0); }
 
   void CassiniSoldner::Reset(real lat0, real lon0) {
@@ -29,11 +25,9 @@ namespace GeographicLib {
                             Geodesic::LATITUDE | Geodesic::LONGITUDE |
                             Geodesic::DISTANCE | Geodesic::DISTANCE_IN |
                             Geodesic::AZIMUTH);
-    real
-      phi = LatitudeOrigin() * Math::degree(),
-      f = _earth.Flattening();
-    _sbet0 = (1 - f) * sin(phi);
-    _cbet0 = abs(LatitudeOrigin()) == 90 ? 0 : cos(phi);
+    real f = _earth.Flattening();
+    Math::sincosd(LatitudeOrigin(), _sbet0, _cbet0);
+    _sbet0 *= (1 - f);
     Math::norm(_sbet0, _cbet0);
   }
 
@@ -41,16 +35,13 @@ namespace GeographicLib {
                                real& azi, real& rk) const {
     if (!Init())
       return;
-    real dlon = Math::AngDiff(LongitudeOrigin(), Math::AngNormalize(lon));
+    real dlon = Math::AngDiff(LongitudeOrigin(), lon);
     real sig12, s12, azi1, azi2;
-    lat = Math::AngRound(lat);
     sig12 = _earth.Inverse(lat, -abs(dlon), lat, abs(dlon), s12, azi1, azi2);
-    if (sig12 < 100 * tiny_)
-      sig12 = s12 = 0;
     sig12 *= real(0.5);
     s12 *= real(0.5);
     if (s12 == 0) {
-      real da = (azi2 - azi1)/2;
+      real da = Math::AngDiff(azi1, azi2)/2;
       if (abs(dlon) <= 90) {
         azi1 = 90 - da;
         azi2 = 90 + da;
@@ -72,9 +63,9 @@ namespace GeographicLib {
                      Geodesic::GEODESICSCALE,
                      t, t, t, t, t, t, rk, t);
 
+    real salp0, calp0;
+    Math::sincosd(perp.EquatorialAzimuth(), salp0, calp0);
     real
-      alp0 = perp.EquatorialAzimuth() * Math::degree(),
-      calp0 = cos(alp0), salp0 = sin(alp0),
       sbet1 = lat >=0 ? calp0 : -calp0,
       cbet1 = abs(dlon) <= 90 ? abs(salp0) : -abs(salp0),
       sbet01 = sbet1 * _cbet0 - cbet1 * _sbet0,
