@@ -36,10 +36,9 @@ namespace GeographicLib {
                                        real lat1, real lon1, real azi1,
                                        unsigned caps)
     : tiny_(g.tiny_)
-    , _lat1(lat1)
+    , _lat1(Math::LatFix(lat1))
     , _lon1(lon1)
-    // Guard against underflow in salp0
-    , _azi1(Math::AngRound(Math::AngNormalize(azi1)))
+    , _azi1(Math::AngNormalize(azi1))
     , _a(g._a)
     , _f(g._f)
     , _b(g._b)
@@ -47,20 +46,15 @@ namespace GeographicLib {
     , _f1(g._f1)
     , _e2(g._e2)
     , _E(0, 0)
-      // Always allow latitude and azimuth
-    , _caps(caps | LATITUDE | AZIMUTH)
+      // Always allow latitude and azimuth and unrolling of longitude
+    , _caps(caps | LATITUDE | AZIMUTH | LONG_UNROLL)
   {
-    real alp1 = _azi1 * Math::degree();
-    // Enforce sin(pi) == 0 and cos(pi/2) == 0.  Better to face the ensuing
-    // problems directly than to skirt them.
-    _salp1 =     _azi1  == -180 ? 0 : sin(alp1);
-    _calp1 = abs(_azi1) ==   90 ? 0 : cos(alp1);
-    real cbet1, sbet1, phi;
-    phi = lat1 * Math::degree();
+    // Guard against underflow in salp0
+    Math::sincosd(Math::AngRound(_azi1), _salp1, _calp1);
+    real cbet1, sbet1;
+    Math::sincosd(Math::AngRound(_lat1), sbet1, cbet1); sbet1 *= _f1;
     // Ensure cbet1 = +epsilon at poles
-    sbet1 = _f1 * sin(phi);
-    cbet1 = abs(lat1) == 90 ? tiny_ : cos(phi);
-    Math::norm(sbet1, cbet1);
+    Math::norm(sbet1, cbet1); cbet1 = max(tiny_, cbet1);
     _dn1 = (_f >= 0 ? sqrt(1 + g._ep2 * Math::sq(sbet1)) :
             sqrt(1 - _e2 * Math::sq(cbet1)) / _f1);
 
@@ -179,32 +173,31 @@ namespace GeographicLib {
 
     if (outmask & LONGITUDE) {
       real somg2 = _salp0 * ssig2, comg2 = csig2;  // No need to normalize
+      int E = _salp0 < 0 ? -1 : 1;                 // east-going?
       // Without normalization we have schi2 = somg2.
       real cchi2 =  _f1 * dn2 *  comg2;
-      real chi12 = outmask & LONG_NOWRAP ? sig12
-        - (atan2(ssig2, csig2) - atan2(_ssig1, _csig1))
-        + (atan2(somg2, cchi2) - atan2(_somg1, _cchi1))
+      real chi12 = outmask & LONG_UNROLL
+        ? E * (sig12
+               - (atan2(    ssig2, csig2) - atan2(    _ssig1, _csig1))
+               + (atan2(E * somg2, cchi2) - atan2(E * _somg1, _cchi1)))
         : atan2(somg2 * _cchi1 - cchi2 * _somg1,
                 cchi2 * _cchi1 + somg2 * _somg1);
       real lam12 = chi12 -
-        _e2/_f1 * _salp0 * _H0 * (sig12 + _E.deltaH(ssig2, csig2, dn2) - _H1 );
+        _e2/_f1 * _salp0 * _H0 * (sig12 + (_E.deltaH(ssig2, csig2, dn2) - _H1));
       real lon12 = lam12 / Math::degree();
-      // Use Math::AngNormalize2 because longitude might have wrapped
-      // multiple times.
-      lon2 = outmask & LONG_NOWRAP ? _lon1 + lon12 :
+      lon2 = outmask & LONG_UNROLL ? _lon1 + lon12 :
         Math::AngNormalize(Math::AngNormalize(_lon1) +
-                           Math::AngNormalize2(lon12));
+                           Math::AngNormalize(lon12));
     }
 
     if (outmask & LATITUDE)
-      lat2 = atan2(sbet2, _f1 * cbet2) / Math::degree();
+      lat2 = Math::atan2d(sbet2, _f1 * cbet2);
 
     if (outmask & AZIMUTH)
-      // minus signs give range [-180, 180). 0- converts -0 to +0.
       azi2 = Math::atan2d(salp2, calp2);
 
     if (outmask & (REDUCEDLENGTH | GEODESICSCALE)) {
-      real J12 = _k2 * _D0 * (sig12 + _E.deltaD(ssig2, csig2, dn2) - _D1);
+      real J12 = _k2 * _D0 * (sig12 + (_E.deltaD(ssig2, csig2, dn2) - _D1));
       if (outmask & REDUCEDLENGTH)
         // Add parens around (_csig1 * ssig2) and (_ssig1 * csig2) to ensure
         // accurate cancellation in the case of coincident points.
