@@ -2,7 +2,7 @@
  * \file Geohash.cpp
  * \brief Implementation for GeographicLib::Geohash class
  *
- * Copyright (c) Charles Karney (2012-2014) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2012-2015) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * http://geographiclib.sourceforge.net/
  **********************************************************************/
@@ -14,30 +14,28 @@ namespace GeographicLib {
 
   using namespace std;
 
-  const int Geohash::decprec_[] = {-2, -1, 0, 0, 1, 2, 3, 3, 4, 5,
-                                   6, 6, 7, 8, 9, 9, 10, 11, 12};
   const string Geohash::lcdigits_ = "0123456789bcdefghjkmnpqrstuvwxyz";
   const string Geohash::ucdigits_ = "0123456789BCDEFGHJKMNPQRSTUVWXYZ";
 
   void Geohash::Forward(real lat, real lon, int len, std::string& geohash) {
+    static const real shift = pow(real(2), 45);
+    static const real loneps = 180 / shift;
+    static const real lateps =  90 / shift;
     if (abs(lat) > 90)
       throw GeographicErr("Latitude " + Utility::str(lat)
                           + "d not in [-90d, 90d]");
-    if (lon < -540 || lon >= 540)
-      throw GeographicErr("Longitude " + Utility::str(lon)
-                          + "d not in [-540d, 540d)");
     if (Math::isnan(lat) || Math::isnan(lon)) {
-      geohash = "nan";
+      geohash = "invalid";
       return;
     }
-    if (lat == 90) lat -= lateps() / 2;
+    if (lat == 90) lat -= lateps / 2;
     lon = Math::AngNormalize(lon); // lon in [-180,180)
     // lon/loneps in [-2^45,2^45); lon/loneps + shift in [0,2^46)
     // similarly for lat
     len = max(0, min(int(maxlen_), len));
     unsigned long long
-      ulon = (unsigned long long)(floor(lon/loneps()) + shift()),
-      ulat = (unsigned long long)(floor(lat/lateps()) + shift());
+      ulon = (unsigned long long)(floor(lon/loneps) + shift),
+      ulat = (unsigned long long)(floor(lat/lateps) + shift);
     char geohash1[maxlen_];
     unsigned byte = 0;
     for (unsigned i = 0; i < 5 * unsigned(len);) {
@@ -60,16 +58,23 @@ namespace GeographicLib {
 
   void Geohash::Reverse(const std::string& geohash, real& lat, real& lon,
                         int& len, bool centerp) {
-    len = min(int(maxlen_), int(geohash.length()));
-    if (len >= 3 &&
-        toupper(geohash[0]) == 'N' &&
-        toupper(geohash[1]) == 'A' &&
-        toupper(geohash[2]) == 'N') {
+    static const real shift = pow(real(2), 45);
+    static const real loneps = 180 / shift;
+    static const real lateps =  90 / shift;
+    int len1 = min(int(maxlen_), int(geohash.length()));
+    if (len1 >= 3 &&
+        ((toupper(geohash[0]) == 'I' &&
+          toupper(geohash[1]) == 'N' &&
+          toupper(geohash[2]) == 'V') ||
+         // Check A first because it is not in a standard geohash
+         (toupper(geohash[1]) == 'A' &&
+          toupper(geohash[0]) == 'N' &&
+          toupper(geohash[2]) == 'N'))) {
       lat = lon = Math::NaN();
       return;
     }
     unsigned long long ulon = 0, ulat = 0;
-    for (unsigned k = 0, j = 0; k < unsigned(len); ++k) {
+    for (unsigned k = 0, j = 0; k < unsigned(len1); ++k) {
       int byte = Utility::lookup(ucdigits_, geohash[k]);
       if (byte < 0)
         throw GeographicErr("Illegal character in geohash " + geohash);
@@ -86,11 +91,12 @@ namespace GeographicLib {
       ulon += 1;
       ulat += 1;
     }
-    int s = 5 * (maxlen_ - len);
+    int s = 5 * (maxlen_ - len1);
     ulon <<=     (s / 2);
     ulat <<= s - (s / 2);
-    lon = ulon * loneps() - 180;
-    lat = ulat * lateps() - 90;
+    lon = ulon * loneps - 180;
+    lat = ulat * lateps - 90;
+    len = len1;
   }
 
 } // namespace GeographicLib
