@@ -62,7 +62,9 @@ namespace GeographicLib {
         throw GeographicErr("ID mismatch: " + _id + " vs " + id);
       int N, M;
       SphericalEngine::coeff::readcoeffs(coeffstr, N, M, _Cx, _Sx);
-      if (!(M < 0 || _Cx[0] == 0))
+      if (!(N >= 0 && M >= 0))
+        throw GeographicErr("Degree and order must be at least 0");
+      if (_Cx[0] != 0)
         throw GeographicErr("A degree 0 term should be zero");
       _Cx[0] = 1;               // Include the 1/r term in the sum
       _gravitational = SphericalHarmonic(_Cx, _Sx, N, N, M, _amodel, _norm);
