@@ -2,7 +2,7 @@
  * \file LocalCartesian.cpp
  * \brief Implementation for GeographicLib::LocalCartesian class
  *
- * Copyright (c) Charles Karney (2008-2011) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2008-2015) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * http://geographiclib.sourceforge.net/
  **********************************************************************/
@@ -14,17 +14,13 @@ namespace GeographicLib {
   using namespace std;
 
   void LocalCartesian::Reset(real lat0, real lon0, real h0) {
-    _lat0 = lat0;
+    _lat0 = Math::LatFix(lat0);
     _lon0 = Math::AngNormalize(lon0);
     _h0 = h0;
     _earth.Forward(_lat0, _lon0, _h0, _x0, _y0, _z0);
-    real
-      phi = lat0 * Math::degree(),
-      sphi = sin(phi),
-      cphi = abs(_lat0) == 90 ? 0 : cos(phi),
-      lam = lon0 * Math::degree(),
-      slam = _lon0 == -180 ? 0 : sin(lam),
-      clam = abs(_lon0) == 90 ? 0 : cos(lam);
+    real sphi, cphi, slam, clam;
+    Math::sincosd(_lat0, sphi, cphi);
+    Math::sincosd(_lon0, slam, clam);
     Geocentric::Rotation(sphi, cphi, slam, clam, _r);
   }
 
