@@ -47,7 +47,7 @@ namespace GeographicLib {
 
   TransverseMercator::TransverseMercator(real a, real f, real k0)
     : _a(a)
-    , _f(f <= 1 ? f : 1/f)
+    , _f(f <= 1 ? f : 1/f)      // f > 1 behavior is DEPRECATED
     , _k0(k0)
     , _e2(_f * (2 - _f))
     , _es((f < 0 ? -1 : 1) * sqrt(abs(_e2)))
