@@ -2,7 +2,7 @@
  * \file GeodSolve.cpp
  * \brief Command line utility for geodesic calculations
  *
- * Copyright (c) Charles Karney (2009-2012) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2009-2015) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * http://geographiclib.sourceforge.net/
  *
@@ -31,19 +31,22 @@
 
 typedef GeographicLib::Math::real real;
 
-std::string LatLonString(real lat, real lon, int prec, bool dms, char dmssep) {
+std::string LatLonString(real lat, real lon, int prec, bool dms, char dmssep,
+                         bool longfirst) {
   using namespace GeographicLib;
-  return dms ?
-    DMS::Encode(lat, prec + 5, DMS::LATITUDE, dmssep) + " " +
-    DMS::Encode(lon, prec + 5, DMS::LONGITUDE, dmssep) :
-    DMS::Encode(lat, prec + 5, DMS::NUMBER) + " " +
+  std::string
+    latstr = dms ? DMS::Encode(lat, prec + 5, DMS::LATITUDE, dmssep) :
+    DMS::Encode(lat, prec + 5, DMS::NUMBER),
+    lonstr = dms ? DMS::Encode(lon, prec + 5, DMS::LONGITUDE, dmssep) :
     DMS::Encode(lon, prec + 5, DMS::NUMBER);
+  return
+    (longfirst ? lonstr : latstr) + " " + (longfirst ? latstr : lonstr);
 }
 
 std::string AzimuthString(real azi, int prec, bool dms, char dmssep) {
   using namespace GeographicLib;
   return dms ? DMS::Encode(azi, prec + 5, DMS::AZIMUTH, dmssep) :
-    DMS::Encode(azi >= 180 ? azi - 360 : azi, prec + 5, DMS::NUMBER);
+    DMS::Encode(azi, prec + 5, DMS::NUMBER);
 }
 
 std::string DistanceStrings(real s12, real a12,
@@ -69,12 +72,12 @@ int main(int argc, char* argv[]) {
     using namespace GeographicLib;
     Utility::set_digits();
     bool linecalc = false, inverse = false, arcmode = false,
-      dms = false, full = false, exact = false;
+      dms = false, full = false, exact = false, unroll = false,
+      longfirst = false, azi2back = false;
     real
       a = Constants::WGS84_a(),
       f = Constants::WGS84_f();
     real lat1, lon1, azi1, lat2, lon2, azi2, s12, m12, a12, M12, M21, S12;
-    real azi2sense = 0;
     int prec = 3;
     std::string istring, ifile, ofile, cdelim;
     char lsep = ';', dmssep = char(0);
@@ -92,7 +95,7 @@ int main(int argc, char* argv[]) {
         if (m + 3 >= argc) return usage(1, true);
         try {
           DMS::DecodeLatLon(std::string(argv[m + 1]), std::string(argv[m + 2]),
-                            lat1, lon1);
+                            lat1, lon1, longfirst);
           azi1 = DMS::DecodeAzimuth(std::string(argv[m + 3]));
         }
         catch (const std::exception& e) {
@@ -111,15 +114,18 @@ int main(int argc, char* argv[]) {
           return 1;
         }
         m += 2;
-      }
+      } else if (arg == "-u")
+        unroll = true;
       else if (arg == "-d") {
         dms = true;
         dmssep = '\0';
       } else if (arg == "-:") {
         dms = true;
         dmssep = ':';
-      } else if (arg == "-b")
-        azi2sense = 180;
+      } else if (arg == "-w")
+        longfirst = true;
+      else if (arg == "-b")
+        azi2back = true;
       else if (arg == "-f")
         full = true;
       else if (arg == "-p") {
@@ -153,9 +159,8 @@ int main(int argc, char* argv[]) {
         if (++m == argc) return usage(1, true);
         cdelim = argv[m];
       } else if (arg == "--version") {
-        std::cout
-          << argv[0] << ": GeographicLib version "
-          << GEOGRAPHICLIB_VERSION_STRING << "\n";
+        std::cout << argv[0] << ": GeographicLib version "
+                  << GEOGRAPHICLIB_VERSION_STRING << "\n";
         return 0;
       } else
         return usage(!(arg == "-h" || arg == "--help"), arg != "--help");
@@ -198,25 +203,38 @@ int main(int argc, char* argv[]) {
     }
     std::ostream* output = !ofile.empty() ? &outfile : &std::cout;
 
-    const Geodesic geod(a, f);
+    // GeodesicExact mask values are the same as Geodesic
+    unsigned outmask = Geodesic::LATITUDE | Geodesic::LONGITUDE |
+      Geodesic::AZIMUTH;        // basic output quantities
+    outmask |= inverse ? Geodesic::DISTANCE : // distance-related flags
+      (arcmode ? Geodesic::NONE : Geodesic::DISTANCE_IN);
+    // longitude unrolling
+    outmask |= unroll ? Geodesic::LONG_UNROLL : Geodesic::NONE;
+    // full output -- don't use Geodesic::ALL since this includes DISTANCE_IN
+    outmask |= full ? (Geodesic::DISTANCE | Geodesic::REDUCEDLENGTH |
+                       Geodesic::GEODESICSCALE | Geodesic::AREA) :
+      Geodesic::NONE;
+
+    const Geodesic      geods(a, f);
     const GeodesicExact geode(a, f);
-    GeodesicLine l;
+    GeodesicLine      ls;
     GeodesicLineExact le;
     if (linecalc) {
       if (exact)
-        le = geode.Line(lat1, lon1, azi1);
+        le = geode.Line(lat1, lon1, azi1, outmask);
       else
-        l = geod.Line(lat1, lon1, azi1);
+        ls = geods.Line(lat1, lon1, azi1, outmask);
     }
 
     // Max precision = 10: 0.1 nm in distance, 10^-15 deg (= 0.11 nm),
     // 10^-11 sec (= 0.3 nm).
     prec = std::min(10 + Math::extra_digits(), std::max(0, prec));
-    std::string s;
+    std::string s, eol, slat1, slon1, slat2, slon2, sazi1, ss12, strc;
+    std::istringstream str;
     int retval = 0;
     while (std::getline(*input, s)) {
       try {
-        std::string eol("\n");
+        eol = "\n";
         if (!cdelim.empty()) {
           std::string::size_type m = s.find(cdelim);
           if (m != std::string::npos) {
@@ -224,27 +242,36 @@ int main(int argc, char* argv[]) {
             s = s.substr(0, m);
           }
         }
-        std::istringstream str(s);
+        str.clear(); str.str(s);
         if (inverse) {
-          std::string slat1, slon1, slat2, slon2;
           if (!(str >> slat1 >> slon1 >> slat2 >> slon2))
             throw GeographicErr("Incomplete input: " + s);
-          std::string strc;
           if (str >> strc)
             throw GeographicErr("Extraneous input: " + strc);
-          DMS::DecodeLatLon(slat1, slon1, lat1, lon1);
-          DMS::DecodeLatLon(slat2, slon2, lat2, lon2);
+          DMS::DecodeLatLon(slat1, slon1, lat1, lon1, longfirst);
+          DMS::DecodeLatLon(slat2, slon2, lat2, lon2, longfirst);
           a12 = exact ?
-            geode.Inverse(lat1, lon1, lat2, lon2, s12, azi1, azi2,
-                          m12, M12, M21, S12) :
-            geod.Inverse(lat1, lon1, lat2, lon2, s12, azi1, azi2,
-                         m12, M12, M21, S12);
-          if (full)
-            *output << LatLonString(lat1, lon1, prec, dms, dmssep) << " ";
+            geode.GenInverse(lat1, lon1, lat2, lon2, outmask,
+                             s12, azi1, azi2, m12, M12, M21, S12) :
+            geods.GenInverse(lat1, lon1, lat2, lon2, outmask,
+                             s12, azi1, azi2, m12, M12, M21, S12);
+          if (full) {
+            if (unroll)
+              lon2 = lon1 + Math::AngDiff(lon1, lon2);
+            else {
+              lon1 = Math::AngNormalize(lon1);
+              lon2 = Math::AngNormalize(lon2);
+            }
+            *output << LatLonString(lat1, lon1, prec, dms, dmssep, longfirst)
+                    << " ";
+          }
           *output << AzimuthString(azi1, prec, dms, dmssep) << " ";
           if (full)
-            *output << LatLonString(lat2, lon2, prec, dms, dmssep) << " ";
-          *output << AzimuthString(azi2 + azi2sense, prec, dms, dmssep) << " "
+            *output << LatLonString(lat2, lon2, prec, dms, dmssep, longfirst)
+                    << " ";
+          if (azi2back)
+            azi2 += azi2 >= 0 ? -180 : 180;
+          *output << AzimuthString(azi2, prec, dms, dmssep) << " "
                   << DistanceStrings(s12, a12, full, arcmode, prec, dms);
           if (full)
             *output << " " << Utility::str(m12, prec)
@@ -254,51 +281,39 @@ int main(int argc, char* argv[]) {
           *output << eol;
         } else {
           if (linecalc) {
-            std::string ss12;
             if (!(str >> ss12))
               throw GeographicErr("Incomplete input: " + s);
-            std::string strc;
             if (str >> strc)
               throw GeographicErr("Extraneous input: " + strc);
             s12 = ReadDistance(ss12, arcmode);
-            if (arcmode)
-              exact ?
-                le.ArcPosition(s12, lat2, lon2, azi2, a12, m12, M12, M21, S12) :
-                l.ArcPosition(s12, lat2, lon2, azi2, a12, m12, M12, M21, S12);
-            else
-              a12 = exact ?
-                le.Position(s12, lat2, lon2, azi2, m12, M12, M21, S12) :
-                l.Position(s12, lat2, lon2, azi2, m12, M12, M21, S12);
+            a12 = exact ?
+              le.GenPosition(arcmode, s12, outmask,
+                             lat2, lon2, azi2, s12, m12, M12, M21, S12) :
+              ls.GenPosition(arcmode, s12, outmask,
+                             lat2, lon2, azi2, s12, m12, M12, M21, S12);
           } else {
-            std::string slat1, slon1, sazi1, ss12;
             if (!(str >> slat1 >> slon1 >> sazi1 >> ss12))
               throw GeographicErr("Incomplete input: " + s);
-            std::string strc;
             if (str >> strc)
               throw GeographicErr("Extraneous input: " + strc);
-            DMS::DecodeLatLon(slat1, slon1, lat1, lon1);
+            DMS::DecodeLatLon(slat1, slon1, lat1, lon1, longfirst);
             azi1 = DMS::DecodeAzimuth(sazi1);
             s12 = ReadDistance(ss12, arcmode);
-            if (arcmode)
-              exact ?
-                geode.ArcDirect(lat1, lon1, azi1, s12, lat2, lon2, azi2, a12,
-                                m12, M12, M21, S12) :
-                geod.ArcDirect(lat1, lon1, azi1, s12, lat2, lon2, azi2, a12,
-                               m12, M12, M21, S12);
-            else
-              a12 = exact ?
-                geode.Direct(lat1, lon1, azi1, s12, lat2, lon2, azi2,
-                             m12, M12, M21, S12) :
-                geod.Direct(lat1, lon1, azi1, s12, lat2, lon2, azi2,
-                            m12, M12, M21, S12);
+            a12 = exact ?
+              geode.GenDirect(lat1, lon1, azi1, arcmode, s12, outmask,
+                              lat2, lon2, azi2, s12, m12, M12, M21, S12) :
+              geods.GenDirect(lat1, lon1, azi1, arcmode, s12, outmask,
+                              lat2, lon2, azi2, s12, m12, M12, M21, S12);
           }
-          if (arcmode)
-            std::swap(s12, a12);
           if (full)
-            *output << LatLonString(lat1, lon1, prec, dms, dmssep) << " "
-                    << AzimuthString(azi1, prec, dms, dmssep) << " ";
-          *output << LatLonString(lat2, lon2, prec, dms, dmssep) << " "
-                  << AzimuthString(azi2 + azi2sense, prec, dms, dmssep);
+            *output
+              << LatLonString(lat1, unroll ? lon1 : Math::AngNormalize(lon1),
+                              prec, dms, dmssep, longfirst)
+              << " " << AzimuthString(azi1, prec, dms, dmssep) << " ";
+          if (azi2back)
+            azi2 += azi2 >= 0 ? -180 : 180;
+          *output << LatLonString(lat2, lon2, prec, dms, dmssep, longfirst)
+                  << " " << AzimuthString(azi2, prec, dms, dmssep);
           if (full)
             *output << " "
                     << DistanceStrings(s12, a12, full, arcmode, prec, dms)
