@@ -36,8 +36,6 @@ In addition you can specify
   all = all of the supported gravity models
   minimal = egm96 wgs84
 
-If no name is specified then minimal is assumed.
-
 -p parentdir (default $DEFAULTDIR) specifies where the
 datasets should be stored.  The "Default $NAME path" listed when running
 
@@ -82,6 +80,10 @@ while getopts hp:fd c; do
     esac
 done
 shift `expr $OPTIND - 1`
+if test $# -eq 0; then
+    usage 1>&2;
+    exit 1
+fi
 
 test -d "$PARENTDIR"/$SUBDIR || mkdir -p "$PARENTDIR"/$SUBDIR 2> /dev/null
 if test ! -d "$PARENTDIR"/$SUBDIR; then
@@ -119,8 +121,6 @@ grs80
 wgs84
 EOF
 
-test $# -eq 0 && set -- minimal
-
 while test $# -gt 0; do
     if grep "^$1\$" $TEMP/all > /dev/null; then
 	echo $1
@@ -129,7 +129,7 @@ while test $# -gt 0; do
 	    all )
 		cat $TEMP/all
 		;;
-	    minimal )		# same as no argument
+	    minimal )
 		echo egm96; echo wgs84
 		;;
 	    * )
