@@ -29,6 +29,7 @@ table:
   igrf11     13    1900-2015      7      25
   igrf12     13    1900-2020      7      26
   emm2010   740    2010-2015    3700    4400
+  emm2015   730    2000-2020     660    4300
 
 The size columns give the download and installed sizes of the datasets.
 In addition you can specify
@@ -116,6 +117,7 @@ cat > $TEMP/all <<EOF
 wmm2010
 wmm2015
 emm2010
+emm2015
 igrf11
 igrf12
 EOF
